======================
USB-ISS Python Library
======================


.. image:: https://img.shields.io/pypi/v/usb_iss.svg
        :target: https://pypi.python.org/pypi/usb_iss

.. image:: https://img.shields.io/travis/sneakypete81/usb_iss.svg
        :target: https://travis-ci.org/sneakypete81/usb_iss

.. image:: https://pyup.io/repos/github/sneakypete81/usb_iss/shield.svg
     :target: https://pyup.io/repos/github/sneakypete81/usb_iss/
     :alt: Updates



Python library for the USB-ISS board.


* Free software: GNU General Public License v3


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
